( cd usr/X11R7/lib ; rm -rf libXaw.so.6 )
( cd usr/X11R7/lib ; ln -sf libXaw6.so.6 libXaw.so.6 )
( cd usr/X11R7/lib ; rm -rf libXaw.so.7 )
( cd usr/X11R7/lib ; ln -sf libXaw7.so.7 libXaw.so.7 )
( cd usr/X11R7/lib ; rm -rf libXaw6.so.6 )
( cd usr/X11R7/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so.6 )
( cd usr/X11R7/lib ; rm -rf libXaw7.so.7 )
( cd usr/X11R7/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so.7 )
( cd usr/X11R7/lib ; rm -rf libXaw.so )
( cd usr/X11R7/lib ; ln -sf libXaw7.so libXaw.so )
( cd usr/X11R7/lib ; rm -rf libXaw6.so )
( cd usr/X11R7/lib ; ln -sf libXaw6.so.6.0.1 libXaw6.so )
( cd usr/X11R7/lib ; rm -rf libXaw7.so )
( cd usr/X11R7/lib ; ln -sf libXaw7.so.7.0.0 libXaw7.so )
